@@ -1,16 +1,19 @@
+from __future__ import annotations
+
 import re
-from collections.abc import Iterable, Mapping, Sequence
 from typing import TYPE_CHECKING, Annotated, Any
 
 from ..exceptions import ConfigValidationError, ExpressionParseError
-from ..executor.task_run import PoeTaskRun
 from ..options.annotations import Metadata
 from .base import PoeTask
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable, Mapping, Sequence
+
     from ..config import PoeConfig
     from ..context import RunContext
     from ..env.manager import EnvVarsManager
+    from ..executor.task_run import PoeTaskRun
     from .base import TaskSpecFactory
 
 
@@ -24,9 +27,10 @@ class ExprTask(PoeTask):
     __key__ = "expr"
 
     class TaskOptions(PoeTask.TaskOptions):
-        imports: Sequence[str] = tuple()
+        imports: Sequence[str] = ()
         assert_: Annotated[bool | int, Metadata(config_name="assert")] = False
         use_exec: bool = False
+        ignore_fail: bool | list[int] = False
 
         def validate(self):
             super().validate()
@@ -38,9 +42,9 @@ class ExprTask(PoeTask):
 
     class TaskSpec(PoeTask.TaskSpec):
         content: str
-        options: "ExprTask.TaskOptions"
+        options: ExprTask.TaskOptions
 
-        def _task_validations(self, config: "PoeConfig", task_specs: "TaskSpecFactory"):
+        def _task_validations(self, config: PoeConfig, task_specs: TaskSpecFactory):
             """
             Perform validations on this TaskSpec that apply to a specific task type
             """
@@ -52,10 +56,13 @@ class ExprTask(PoeTask):
     spec: TaskSpec
 
     async def _handle_run(
-        self, context: "RunContext", env: "EnvVarsManager", task_state: PoeTaskRun
+        self, context: RunContext, env: EnvVarsManager, task_state: PoeTaskRun
     ):
         from ..helpers.python import format_class
 
+        if ignore_fail := self.spec.options.ignore_fail:
+            task_state.ignore_failure(ignore_fail)
+
         named_arg_values, _ = self.get_parsed_arguments(env)
         env.update(named_arg_values)
 
@@ -93,7 +100,7 @@ class ExprTask(PoeTask):
     def parse_content(
         self,
         args: dict[str, Any] | None,
-        env: "EnvVarsManager",
+        env: EnvVarsManager,
         imports: Iterable[str],
     ) -> tuple[str, dict[str, str]]:
         """
@@ -113,7 +120,7 @@ class ExprTask(PoeTask):
 
         expression = resolve_expression(
             source=expression,
-            arguments=set(args or tuple()),
+            arguments=set(args or ()),
             allowed_vars={"sys", "__env", *imports},
         )
         # Strip out any new lines because they can be problematic on windows
